The ECCW project contributors is composed of:

* BCL Mary
  - main author
  - maintener
  - python implementation of computing core
  - GUI design and implementation
  - graphics design
* YM Leroy 
  - original fortran implementation of computing core 
  - author of exact solution of ECCW
* Xiaoping Yuan
  - main author of exact solution of ECCW
* Pauline Souloumiac
  - GUI design
  - testings
* Chong Wu 
  - help on GUI implementation
